==> jc-1.4.0.tar.gz: gnu/xml/transform/AttributeSet.c <==
// final class gnu.xml.transform.AttributeSet

// class file dependencies
// @dep_class 60a08c7ac570a92a gnu_xml_transform_AttributeSet
// @dep_class 83e341b0773e8a08 gnu_xml_transform_Stylesheet
// @dep_class ef8509869908c7a6 gnu_xml_transform_TemplateNode
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String

// header file dependencies
// @dep_header gnu_xml_transform_AttributeSet
// @dep_header gnu_xml_transform_Stylesheet
// @dep_header gnu_xml_transform_TemplateNode
// @dep_header java_lang_Class
// @dep_header java_lang_String

#include "jc_defs.h"

#include "gnu/xml/transform/AttributeSet.h"
#include "gnu/xml/transform/Stylesheet.h"
#include "gnu/xml/transform/TemplateNode.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// final gnu.xml.transform.TemplateNode children
static _jc_field _jc_gnu_xml_transform_AttributeSet$field_info$children = {
	.name=		"children",
	.signature=	"Lgnu/xml/transform/TemplateNode;",
	.class=		&_jc_gnu_xml_transform_AttributeSet$type,
	.type=		&_jc_gnu_xml_transform_TemplateNode$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_gnu_xml_transform_AttributeSet$object, refs[-1].gnu_xml_transform_AttributeSet.children),
};

// final java.lang.String name
static _jc_field _jc_gnu_xml_transform_AttributeSet$field_info$name = {
	.name=		"name",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_gnu_xml_transform_AttributeSet$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_gnu_xml_transform_AttributeSet$object, refs[-1].gnu_xml_transform_AttributeSet.name),
};

// final java.lang.String uas
static _jc_field _jc_gnu_xml_transform_AttributeSet$field_info$uas = {
	.name=		"uas",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_gnu_xml_transform_AttributeSet$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_gnu_xml_transform_AttributeSet$object, refs[-1].gnu_xml_transform_AttributeSet.uas),
};

// Fields
static _jc_field *const _jc_gnu_xml_transform_AttributeSet$fields[] = {
	&_jc_gnu_xml_transform_AttributeSet$field_info$children,
	&_jc_gnu_xml_transform_AttributeSet$field_info$name,
	&_jc_gnu_xml_transform_AttributeSet$field_info$uas
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>(gnu.xml.transform.TemplateNode, java.lang.String, java.lang.String)
//

static _jc_linenum _jc_gnu_xml_transform_AttributeSet$linenum_table$_init$737e1cf96a1d352c[];

static const unsigned char _jc_gnu_xml_transform_AttributeSet$param_ptypes$_init$737e1cf96a1d352c[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_gnu_xml_transform_AttributeSet$param_types$_init$737e1cf96a1d352c[] = {
	&_jc_gnu_xml_transform_TemplateNode$type,
	&_jc_java_lang_String$type,
	&_jc_java_lang_String$type
};

_jc_method _jc_gnu_xml_transform_AttributeSet$method_info$_init$737e1cf96a1d352c = {
	.name=			"<init>",
	.signature=		"(Lgnu/xml/transform/TemplateNode;Ljava/lang/String;Ljava/lang/String;)V",
	.class=			&_jc_gnu_xml_transform_AttributeSet$type,
	.param_types=		&_jc_gnu_xml_transform_AttributeSet$param_types$_init$737e1cf96a1d352c,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_gnu_xml_transform_AttributeSet$param_ptypes$_init$737e1cf96a1d352c,
	.signature_hash=	_JC_JLONG(0x737e1cf96a1d352c),
	.access_flags=		0,
	.function=		&_jc_gnu_xml_transform_AttributeSet$method$_init$737e1cf96a1d352c,
	.num_parameters=	3,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	4,
	      .table=	_jc_gnu_xml_transform_AttributeSet$linenum_table$_init$737e1cf96a1d352c
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_xml_transform_AttributeSet, _init$737e1cf96a1d352c);

void
_jc_gnu_xml_transform_AttributeSet$method$_init$737e1cf96a1d352c(_jc_env *const env, _jc_gnu_xml_transform_AttributeSet$object *this, _jc_gnu_xml_transform_TemplateNode$object *param0, _jc_java_lang_String$object *param1, _jc_java_lang_String$object *param2)
{
	struct _jc_gnu_xml_transform_AttributeSet$object *r0;
	struct _jc_gnu_xml_transform_TemplateNode$object *r1;
	struct _jc_java_lang_String$object *r2;
	struct _jc_java_lang_String$object *r3;

	r0 = this;
	r1 = param0;
	r2 = param1;
	r3 = param2;
	_JC_LINE_NUMBER(54);				// 0
	_JC_REF_FIELD(env, r0, gnu_xml_transform_AttributeSet, children) = r1;
	_JC_LINE_NUMBER(55);				// 1
	_JC_REF_FIELD(env, r0, gnu_xml_transform_AttributeSet, name) = r2;
	_JC_LINE_NUMBER(56);				// 2
	_JC_REF_FIELD(env, r0, gnu_xml_transform_AttributeSet, uas) = r3;
	_JC_LINE_NUMBER(57);				// 3
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// final gnu.xml.transform.AttributeSet clone(gnu.xml.transform.Stylesheet)
//

static _jc_linenum _jc_gnu_xml_transform_AttributeSet$linenum_table$clone$bffc35b9041a70d9[];

static const unsigned char _jc_gnu_xml_transform_AttributeSet$param_ptypes$clone$bffc35b9041a70d9[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_gnu_xml_transform_AttributeSet$param_types$clone$bffc35b9041a70d9[] = {
	&_jc_gnu_xml_transform_Stylesheet$type
};

_jc_method _jc_gnu_xml_transform_AttributeSet$method_info$clone$bffc35b9041a70d9 = {
	.name=			"clone",
	.signature=		"(Lgnu/xml/transform/Stylesheet;)Lgnu/xml/transform/AttributeSet;",
	.class=			&_jc_gnu_xml_transform_AttributeSet$type,
	.param_types=		&_jc_gnu_xml_transform_AttributeSet$param_types$clone$bffc35b9041a70d9,
	.return_type=		&_jc_gnu_xml_transform_AttributeSet$type,
	.param_ptypes=		&_jc_gnu_xml_transform_AttributeSet$param_ptypes$clone$bffc35b9041a70d9,
	.signature_hash=	_JC_JLONG(0xbffc35b9041a70d9),
	.access_flags=		_JC_ACC_FINAL,
	.function=		&_jc_gnu_xml_transform_AttributeSet$method$clone$bffc35b9041a70d9,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_xml_transform_AttributeSet$vtable, gnu_xml_transform_AttributeSet.clone$bffc35b9041a70d9) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_xml_transform_AttributeSet$linenum_table$clone$bffc35b9041a70d9
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_xml_transform_AttributeSet, clone$bffc35b9041a70d9);

_jc_gnu_xml_transform_AttributeSet$object *
_jc_gnu_xml_transform_AttributeSet$method$clone$bffc35b9041a70d9(_jc_env *const env, _jc_gnu_xml_transform_AttributeSet$object *this, _jc_gnu_xml_transform_Stylesheet$object *param0)
{
	struct _jc_gnu_xml_transform_AttributeSet$object *r0;
	struct _jc_gnu_xml_transform_Stylesheet$object *r1;
	struct _jc_gnu_xml_transform_AttributeSet$object *r2;
	struct _jc_gnu_xml_transform_TemplateNode$object *r3;
	struct _jc_java_lang_String$object *r4;
	struct _jc_java_lang_String$object *r5;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(61);				// 0
	r2 = _JC_NEW(env, gnu_xml_transform_AttributeSet);
	r3 = _JC_REF_FIELD(env, r0, gnu_xml_transform_AttributeSet, children);
	if (r3 != _JC_NULL)
		goto label0;
	r3 = _JC_NULL;
	goto label1;

label0:
	r3 = _JC_REF_FIELD(env, r0, gnu_xml_transform_AttributeSet, children);
	r3 = _JC_INVOKE_VIRTUAL(env, gnu_xml_transform_TemplateNode, clone$b8a038f4254cb648, r3, r1);

label1:
	r4 = _JC_REF_FIELD(env, r0, gnu_xml_transform_AttributeSet, name);
	r5 = _JC_REF_FIELD(env, r0, gnu_xml_transform_AttributeSet, uas);
	_JC_REF_FIELD(env, r2, gnu_xml_transform_AttributeSet, children) = r3;
	_JC_REF_FIELD(env, r2, gnu_xml_transform_AttributeSet, name) = r4;
	_JC_REF_FIELD(env, r2, gnu_xml_transform_AttributeSet, uas) = r5;
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_gnu_xml_transform_AttributeSet$methods[] = {
	&_jc_gnu_xml_transform_AttributeSet$method_info$_init$737e1cf96a1d352c,
	&_jc_gnu_xml_transform_AttributeSet$method_info$clone$bffc35b9041a70d9
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_gnu_xml_transform_AttributeSet$instanceof_hash_bucket_42[] = {
	&_jc_gnu_xml_transform_AttributeSet$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_xml_transform_AttributeSet$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_gnu_xml_transform_AttributeSet$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[42]=	_jc_gnu_xml_transform_AttributeSet$instanceof_hash_bucket_42,
	[113]=	_jc_gnu_xml_transform_AttributeSet$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_gnu_xml_transform_AttributeSet$class_depends[] = {
	{ "gnu/xml/transform/Stylesheet",	_JC_JLONG(0x83e341b0773e8a08) },
	{ "gnu/xml/transform/TemplateNode",	_JC_JLONG(0xef8509869908c7a6) },
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_gnu_xml_transform_AttributeSet$vtype _jc_gnu_xml_transform_AttributeSet$type = {
    .type= {
	.name=			"gnu/xml/transform/AttributeSet",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x60a08c7ac570a92a),
		.source_file=		"AttributeSet.java",
		.instance_size=		sizeof(_jc_gnu_xml_transform_AttributeSet$refs) + sizeof(_jc_gnu_xml_transform_AttributeSet$object),
		.num_virtual_refs=	3,
		.num_fields=		sizeof(_jc_gnu_xml_transform_AttributeSet$fields) / sizeof(*_jc_gnu_xml_transform_AttributeSet$fields),
		.fields=		_jc_gnu_xml_transform_AttributeSet$fields,
		.num_methods=		sizeof(_jc_gnu_xml_transform_AttributeSet$methods) / sizeof(*_jc_gnu_xml_transform_AttributeSet$methods),
		.methods=		_jc_gnu_xml_transform_AttributeSet$methods,
		.instanceof_hash_table=	_jc_gnu_xml_transform_AttributeSet$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_gnu_xml_transform_AttributeSet$class_depends) / sizeof(*_jc_gnu_xml_transform_AttributeSet$class_depends),
		.class_depends=		_jc_gnu_xml_transform_AttributeSet$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.gnu_xml_transform_AttributeSet= {
	    .clone$bffc35b9041a70d9=
		&_jc_gnu_xml_transform_AttributeSet$method$clone$bffc35b9041a70d9,
	},
    }
};

==> jc-1.4.5.tar.gz: gnu/xml/transform/AttributeSet.c <==
// final class gnu.xml.transform.AttributeSet

// class file dependencies
// @dep_class 60a08c7ac570a92a gnu_xml_transform_AttributeSet
// @dep_class 83e341b0773e8a08 gnu_xml_transform_Stylesheet
// @dep_class ef8509869908c7a6 gnu_xml_transform_TemplateNode
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String

// header file dependencies
// @dep_header gnu_xml_transform_AttributeSet
// @dep_header gnu_xml_transform_Stylesheet
// @dep_header gnu_xml_transform_TemplateNode
// @dep_header java_lang_Class
// @dep_header java_lang_String

#include "jc_defs.h"

#include "gnu/xml/transform/AttributeSet.h"
#include "gnu/xml/transform/Stylesheet.h"
#include "gnu/xml/transform/TemplateNode.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// final gnu.xml.transform.TemplateNode children
static _jc_field _jc_gnu_xml_transform_AttributeSet$field_info$children = {
	.name=		"children",
	.signature=	"Lgnu/xml/transform/TemplateNode;",
	.class=		&_jc_gnu_xml_transform_AttributeSet$type,
	.type=		&_jc_gnu_xml_transform_TemplateNode$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_gnu_xml_transform_AttributeSet$object, refs[-1].gnu_xml_transform_AttributeSet.children),
};

// final java.lang.String name
static _jc_field _jc_gnu_xml_transform_AttributeSet$field_info$name = {
	.name=		"name",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_gnu_xml_transform_AttributeSet$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_gnu_xml_transform_AttributeSet$object, refs[-1].gnu_xml_transform_AttributeSet.name),
};

// final java.lang.String uas
static _jc_field _jc_gnu_xml_transform_AttributeSet$field_info$uas = {
	.name=		"uas",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_gnu_xml_transform_AttributeSet$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_gnu_xml_transform_AttributeSet$object, refs[-1].gnu_xml_transform_AttributeSet.uas),
};

// Fields
static _jc_field *const _jc_gnu_xml_transform_AttributeSet$fields[] = {
	&_jc_gnu_xml_transform_AttributeSet$field_info$children,
	&_jc_gnu_xml_transform_AttributeSet$field_info$name,
	&_jc_gnu_xml_transform_AttributeSet$field_info$uas
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>(gnu.xml.transform.TemplateNode, java.lang.String, java.lang.String)
//

static _jc_linenum _jc_gnu_xml_transform_AttributeSet$linenum_table$_init$737e1cf96a1d352c[];

static const unsigned char _jc_gnu_xml_transform_AttributeSet$param_ptypes$_init$737e1cf96a1d352c[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_gnu_xml_transform_AttributeSet$param_types$_init$737e1cf96a1d352c[] = {
	&_jc_gnu_xml_transform_TemplateNode$type,
	&_jc_java_lang_String$type,
	&_jc_java_lang_String$type
};

_jc_method _jc_gnu_xml_transform_AttributeSet$method_info$_init$737e1cf96a1d352c = {
	.name=			"<init>",
	.signature=		"(Lgnu/xml/transform/TemplateNode;Ljava/lang/String;Ljava/lang/String;)V",
	.class=			&_jc_gnu_xml_transform_AttributeSet$type,
	.param_types=		&_jc_gnu_xml_transform_AttributeSet$param_types$_init$737e1cf96a1d352c,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_gnu_xml_transform_AttributeSet$param_ptypes$_init$737e1cf96a1d352c,
	.signature_hash=	_JC_JLONG(0x737e1cf96a1d352c),
	.access_flags=		0,
	.function=		&_jc_gnu_xml_transform_AttributeSet$method$_init$737e1cf96a1d352c,
	.num_parameters=	3,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	4,
	      .table=	_jc_gnu_xml_transform_AttributeSet$linenum_table$_init$737e1cf96a1d352c
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_xml_transform_AttributeSet, _init$737e1cf96a1d352c);

void _JC_JCNI_ATTR
_jc_gnu_xml_transform_AttributeSet$method$_init$737e1cf96a1d352c(_jc_env *const env, _jc_gnu_xml_transform_AttributeSet$object *this, _jc_gnu_xml_transform_TemplateNode$object *param0, _jc_java_lang_String$object *param1, _jc_java_lang_String$object *param2)
{
	struct _jc_gnu_xml_transform_AttributeSet$object *r0;
	struct _jc_gnu_xml_transform_TemplateNode$object *r1;
	struct _jc_java_lang_String$object *r2;
	struct _jc_java_lang_String$object *r3;

	r0 = this;
	r1 = param0;
	r2 = param1;
	r3 = param2;
	_JC_LINE_NUMBER(54);				// 0
	_JC_REF_FIELD(env, r0, gnu_xml_transform_AttributeSet, children) = r1;
	_JC_LINE_NUMBER(55);				// 1
	_JC_REF_FIELD(env, r0, gnu_xml_transform_AttributeSet, name) = r2;
	_JC_LINE_NUMBER(56);				// 2
	_JC_REF_FIELD(env, r0, gnu_xml_transform_AttributeSet, uas) = r3;
	_JC_LINE_NUMBER(57);				// 3
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// final gnu.xml.transform.AttributeSet clone(gnu.xml.transform.Stylesheet)
//

static _jc_linenum _jc_gnu_xml_transform_AttributeSet$linenum_table$clone$bffc35b9041a70d9[];

static const unsigned char _jc_gnu_xml_transform_AttributeSet$param_ptypes$clone$bffc35b9041a70d9[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_gnu_xml_transform_AttributeSet$param_types$clone$bffc35b9041a70d9[] = {
	&_jc_gnu_xml_transform_Stylesheet$type
};

_jc_method _jc_gnu_xml_transform_AttributeSet$method_info$clone$bffc35b9041a70d9 = {
	.name=			"clone",
	.signature=		"(Lgnu/xml/transform/Stylesheet;)Lgnu/xml/transform/AttributeSet;",
	.class=			&_jc_gnu_xml_transform_AttributeSet$type,
	.param_types=		&_jc_gnu_xml_transform_AttributeSet$param_types$clone$bffc35b9041a70d9,
	.return_type=		&_jc_gnu_xml_transform_AttributeSet$type,
	.param_ptypes=		&_jc_gnu_xml_transform_AttributeSet$param_ptypes$clone$bffc35b9041a70d9,
	.signature_hash=	_JC_JLONG(0xbffc35b9041a70d9),
	.access_flags=		_JC_ACC_FINAL,
	.function=		&_jc_gnu_xml_transform_AttributeSet$method$clone$bffc35b9041a70d9,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_xml_transform_AttributeSet$vtable, gnu_xml_transform_AttributeSet.clone$bffc35b9041a70d9) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_xml_transform_AttributeSet$linenum_table$clone$bffc35b9041a70d9
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_xml_transform_AttributeSet, clone$bffc35b9041a70d9);

_jc_gnu_xml_transform_AttributeSet$object * _JC_JCNI_ATTR
_jc_gnu_xml_transform_AttributeSet$method$clone$bffc35b9041a70d9(_jc_env *const env, _jc_gnu_xml_transform_AttributeSet$object *this, _jc_gnu_xml_transform_Stylesheet$object *param0)
{
	struct _jc_gnu_xml_transform_AttributeSet$object *r0;
	struct _jc_gnu_xml_transform_Stylesheet$object *r1;
	struct _jc_gnu_xml_transform_AttributeSet$object *r2;
	struct _jc_gnu_xml_transform_TemplateNode$object *r3;
	struct _jc_java_lang_String$object *r4;
	struct _jc_java_lang_String$object *r5;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(61);				// 0
	r2 = _JC_NEW(env, gnu_xml_transform_AttributeSet);
	r3 = _JC_REF_FIELD(env, r0, gnu_xml_transform_AttributeSet, children);
	if (r3 != _JC_NULL)
		goto label0;
	r3 = _JC_NULL;
	goto label1;

label0:
	r3 = _JC_REF_FIELD(env, r0, gnu_xml_transform_AttributeSet, children);
	r3 = _JC_INVOKE_VIRTUAL(env, gnu_xml_transform_TemplateNode, clone$b8a038f4254cb648, r3, r1);

label1:
	r4 = _JC_REF_FIELD(env, r0, gnu_xml_transform_AttributeSet, name);
	r5 = _JC_REF_FIELD(env, r0, gnu_xml_transform_AttributeSet, uas);
	_JC_REF_FIELD(env, r2, gnu_xml_transform_AttributeSet, children) = r3;
	_JC_REF_FIELD(env, r2, gnu_xml_transform_AttributeSet, name) = r4;
	_JC_REF_FIELD(env, r2, gnu_xml_transform_AttributeSet, uas) = r5;
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_gnu_xml_transform_AttributeSet$methods[] = {
	&_jc_gnu_xml_transform_AttributeSet$method_info$_init$737e1cf96a1d352c,
	&_jc_gnu_xml_transform_AttributeSet$method_info$clone$bffc35b9041a70d9
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_gnu_xml_transform_AttributeSet$instanceof_hash_bucket_42[] = {
	&_jc_gnu_xml_transform_AttributeSet$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_xml_transform_AttributeSet$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_gnu_xml_transform_AttributeSet$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[42]=	_jc_gnu_xml_transform_AttributeSet$instanceof_hash_bucket_42,
	[101]=	_jc_gnu_xml_transform_AttributeSet$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_gnu_xml_transform_AttributeSet$class_depends[] = {
	{ "gnu/xml/transform/Stylesheet",	_JC_JLONG(0x83e341b0773e8a08) },
	{ "gnu/xml/transform/TemplateNode",	_JC_JLONG(0xef8509869908c7a6) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_gnu_xml_transform_AttributeSet$vtype _jc_gnu_xml_transform_AttributeSet$type = {
    .type= {
	.name=			"gnu/xml/transform/AttributeSet",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x60a08c7ac570a92a),
		.source_file=		"AttributeSet.java",
		.instance_size=		sizeof(_jc_gnu_xml_transform_AttributeSet$refs) + sizeof(_jc_gnu_xml_transform_AttributeSet$object),
		.num_virtual_refs=	3,
		.num_fields=		sizeof(_jc_gnu_xml_transform_AttributeSet$fields) / sizeof(*_jc_gnu_xml_transform_AttributeSet$fields),
		.fields=		_jc_gnu_xml_transform_AttributeSet$fields,
		.num_methods=		sizeof(_jc_gnu_xml_transform_AttributeSet$methods) / sizeof(*_jc_gnu_xml_transform_AttributeSet$methods),
		.methods=		_jc_gnu_xml_transform_AttributeSet$methods,
		.instanceof_hash_table=	_jc_gnu_xml_transform_AttributeSet$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_gnu_xml_transform_AttributeSet$class_depends) / sizeof(*_jc_gnu_xml_transform_AttributeSet$class_depends),
		.class_depends=		_jc_gnu_xml_transform_AttributeSet$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.gnu_xml_transform_AttributeSet= {
	    .clone$bffc35b9041a70d9=
		&_jc_gnu_xml_transform_AttributeSet$method$clone$bffc35b9041a70d9,
	},
    }
};
